app <- ShinyDriver$new("../", seed = 1)
app$snapshotInit("3dimBranin")

app$setInputs(objectiveFunction = "rEnv")
app$setInputs(funName = "funBranin")
app$setInputs(addDimension = "click")
app$setInputs(addDimension = "click")
app$setInputs(dimensionType2 = "integer")
app$setInputs(lowerBound2 = -5)
app$setInputs(upperBound2 = 5)
app$setInputs(dimensionAmount2 = 2)
app$setInputs(lowerBound3 = -3)
app$setInputs(upperBound3 = 3)
app$setInputs(tabs = "spotConfig")
Sys.sleep(2)
app$setInputs(tabs = "runMode")
app$setInputs(runSpotIter = "click")
app$setInputs(tabs = "spotConfig")
app$setInputs(tabs = "runMode")
app$setInputs(proposeNewPoint = "click")
app$setInputs(evaluateData = "click")
app$setInputs(runSpotIter = "click")
Sys.sleep(10)
app$snapshot(list(output = "resultTable"))
